==> kadu_0.6.5.1.orig.tar.gz: kadu/modules/notify/translations/notify_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Event</source>
        <translation>Zdarzenie</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>New messages</source>
        <translation>Nowa wiadomość</translation>
    </message>
    <message>
        <source>Notify about new messages only when window is inactive</source>
        <translation>Informuj o nowych wiadomościach tylko gdy okno rozmowy jest nieaktywne</translation>
    </message>
    <message>
        <source>Status change</source>
        <translation>Zmiany statusów</translation>
    </message>
    <message>
        <source>Ignore status changes from available / busy to busy / available</source>
        <translation>Ignoruj zmiany statusów z dostępny / zajęty na zajęty / dostępny</translation>
    </message>
    <message>
        <source>Ignore changes right after connection to the server</source>
        <translation>Ignoruj zmiany statusów po połączeniu z serwerem</translation>
    </message>
    <message>
        <source>This option will supersede tooltips with users&apos; status
 changes upon establishing connection to the server</source>
        <translation>Ta opcja zlikwiduje powiadomienia o zmianach statusów przy łączeniu do serwera</translation>
    </message>
    <message>
        <source>Notify about all users</source>
        <translation>Informuj o wszystkich kontaktach</translation>
    </message>
    <message>
        <source>Connection error</source>
        <translation>Błąd połączenia</translation>
    </message>
    <message>
        <source>User changed status to online</source>
        <translation>Kontakt zmienił status na &apos;Dostępny&apos;</translation>
    </message>
    <message>
        <source>User changed status to busy</source>
        <translation>Kontakt zmienił status na &apos;Zajęty&apos;</translation>
    </message>
    <message>
        <source>User changed status to invisible</source>
        <translation>Kontakt zmienił status na &apos;Ukryty&apos;</translation>
    </message>
    <message>
        <source>User changed status to offline</source>
        <translation>Kontakt zmienił status na &apos;Niedostępny&apos;</translation>
    </message>
    <message>
        <source>New chat</source>
        <translation>Nowa rozmowa</translation>
    </message>
    <message>
        <source>New message</source>
        <translation>Nowa wiadomość</translation>
    </message>
</context>
<context>
    <name>ConnectionErrorNotification</name>
    <message>
        <source>Connection error</source>
        <translation>Błąd połączenia</translation>
    </message>
    <message>
        <source>&lt;b&gt;Error:&lt;/b&gt; (%1) %2</source>
        <translation>&lt;b&gt;Błąd:&lt;/b&gt; (%1) %2</translation>
    </message>
</context>
<context>
    <name>MessageNotification</name>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Rozmowa z &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Nowa wiadomość od &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>Unable to find notifier for %1 event</source>
        <translation>Nie znaleziono powiadomienia dla zdarzenia %1</translation>
    </message>
    <message>
        <source>Move to &apos;Notify list&apos;</source>
        <translation>Przesuń do &quot;Listy powiadomień&quot;</translation>
    </message>
    <message>
        <source>User list</source>
        <translation>Lista kontaktów</translation>
    </message>
    <message>
        <source>Move to &apos;User list&apos;</source>
        <translation>Przesuń do &quot;Listy kontaktów&quot;</translation>
    </message>
    <message>
        <source>Notify list</source>
        <translation>Lista powiadomień</translation>
    </message>
</context>
<context>
    <name>StatusChangedNotification</name>
    <message>
        <source>Status changed</source>
        <translation>Zmiany statusu</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; zmienił status na &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; zmienił status na &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.3.orig.tar.gz: kadu/modules/notify/translations/notify_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Event</source>
        <translation>Zdarzenie</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>New messages</source>
        <translation>Nowa wiadomość</translation>
    </message>
    <message>
        <source>Notify about new messages only when window is inactive</source>
        <translation>Informuj o nowych wiadomościach tylko gdy okno rozmowy jest nieaktywne</translation>
    </message>
    <message>
        <source>Status change</source>
        <translation>Zmiany statusów</translation>
    </message>
    <message>
        <source>Ignore status changes from available / busy to busy / available</source>
        <translation>Ignoruj zmiany statusów z dostępny / zajęty na zajęty / dostępny</translation>
    </message>
    <message>
        <source>Ignore changes right after connection to the server</source>
        <translation>Ignoruj zmiany statusów po połączeniu z serwerem</translation>
    </message>
    <message>
        <source>This option will supersede tooltips with users&apos; status
 changes upon establishing connection to the server</source>
        <translation>Ta opcja zlikwiduje powiadomienia o zmianach statusów przy łączeniu do serwera</translation>
    </message>
    <message>
        <source>Notify about all users</source>
        <translation>Informuj o wszystkich kontaktach</translation>
    </message>
    <message>
        <source>Connection error</source>
        <translation>Błąd połączenia</translation>
    </message>
    <message>
        <source>User changed status to online</source>
        <translation>Kontakt zmienił status na &apos;Dostępny&apos;</translation>
    </message>
    <message>
        <source>User changed status to busy</source>
        <translation>Kontakt zmienił status na &apos;Zajęty&apos;</translation>
    </message>
    <message>
        <source>User changed status to invisible</source>
        <translation>Kontakt zmienił status na &apos;Ukryty&apos;</translation>
    </message>
    <message>
        <source>User changed status to offline</source>
        <translation>Kontakt zmienił status na &apos;Niedostępny&apos;</translation>
    </message>
    <message>
        <source>New chat</source>
        <translation>Nowa rozmowa</translation>
    </message>
    <message>
        <source>New message</source>
        <translation>Nowa wiadomość</translation>
    </message>
    <message>
        <source>Silent Mode</source>
        <translation>Tryb cichy</translation>
    </message>
    <message>
        <source>Enable Silent Mode when Away</source>
        <translation>Włącz tryb cichy gdy jestem Zajęty</translation>
    </message>
</context>
<context>
    <name>ConnectionErrorNotification</name>
    <message>
        <source>Connection error</source>
        <translation>Błąd połączenia</translation>
    </message>
    <message>
        <source>&lt;b&gt;Error:&lt;/b&gt; (%1) %2</source>
        <translation>&lt;b&gt;Błąd:&lt;/b&gt; (%1) %2</translation>
    </message>
</context>
<context>
    <name>MessageNotification</name>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Rozmowa z &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Nowa wiadomość od &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>Unable to find notifier for %1 event</source>
        <translation>Nie znaleziono powiadomienia dla zdarzenia %1</translation>
    </message>
    <message>
        <source>Move to &apos;Notify list&apos;</source>
        <translation>Przesuń do &quot;Listy powiadomień&quot;</translation>
    </message>
    <message>
        <source>User list</source>
        <translation>Lista kontaktów</translation>
    </message>
    <message>
        <source>Move to &apos;User list&apos;</source>
        <translation>Przesuń do &quot;Listy kontaktów&quot;</translation>
    </message>
    <message>
        <source>Notify list</source>
        <translation>Lista powiadomień</translation>
    </message>
    <message>
        <source>Enable Silent Mode</source>
        <translation>Włącz tryb cichy</translation>
    </message>
    <message>
        <source>Disable Silent Mode</source>
        <translation>Wyłącz tryb cichy</translation>
    </message>
</context>
<context>
    <name>StatusChangedNotification</name>
    <message>
        <source>Status changed</source>
        <translation>Zmiany statusu</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; zmienił status na &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; zmienił status na &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
</context>
</TS>
